# encoding: utf-8

module Srbovanje

  ABECEDA = %w(A B C Č Ć D Dž Đ E F G H I J K L Lj M N Nj O P R S Š T U V Z Ž)

  LATINICA_FULL_MAP = {
    "ЉА" => "LJA",
    "АЉ" => "ALJ",
    "ЉБ" => "LJB",
    "БЉ" => "BLJ",
    "ЉВ" => "LJV",
    "ВЉ" => "VLJ",
    "ЉГ" => "LJG",
    "ГЉ" => "GLJ",
    "ЉД" => "LJD",
    "ДЉ" => "DLJ",
    "ЉЂ" => "LJĐ",
    "ЂЉ" => "ĐLJ",
    "ЉЕ" => "LJE",
    "ЕЉ" => "ELJ",
    "ЉЖ" => "LJŽ",
    "ЖЉ" => "ŽLJ",
    "ЉЗ" => "LJZ",
    "ЗЉ" => "ZLJ",
    "ЉИ" => "LJI",
    "ИЉ" => "ILJ",
    "ЉЈ" => "LJJ",
    "ЈЉ" => "JLJ",
    "ЉК" => "LJK",
    "КЉ" => "KLJ",
    "ЉЛ" => "LJL",
    "ЛЉ" => "LLJ",
    "ЉЉ" => "LJLJ",
    "ЉМ" => "LJM",
    "МЉ" => "MLJ",
    "ЉН" => "LJN",
    "НЉ" => "NLJ",
    "ЉЊ" => "LJNJ",
    "ЊЉ" => "NJLJ",
    "ЉО" => "LJO",
    "ОЉ" => "OLJ",
    "ЉП" => "LJP",
    "ПЉ" => "PLJ",
    "ЉР" => "LJR",
    "РЉ" => "RLJ",
    "ЉС" => "LJS",
    "СЉ" => "SLJ",
    "ЉТ" => "LJT",
    "ТЉ" => "TLJ",
    "ЉЋ" => "LJĆ",
    "ЋЉ" => "ĆLJ",
    "ЉЦ" => "LJC",
    "ЦЉ" => "CLJ",
    "ЉУ" => "LJU",
    "УЉ" => "ULJ",
    "ЉФ" => "LJF",
    "ФЉ" => "FLJ",
    "ЉХ" => "LJH",
    "ХЉ" => "HLJ",
    "ЉЧ" => "LJČ",
    "ЧЉ" => "ČLJ",
    "ЉЏ" => "LJDŽ",
    "ЏЉ" => "DŽLJ",
    "ЉШ" => "LJŠ",
    "ШЉ" => "ŠLJ",
    "ЊА" => "NJA",
    "АЊ" => "ANJ",
    "ЊБ" => "NJB",
    "БЊ" => "BNJ",
    "ЊВ" => "NJV",
    "ВЊ" => "VNJ",
    "ЊГ" => "NJG",
    "ГЊ" => "GNJ",
    "ЊД" => "NJD",
    "ДЊ" => "DNJ",
    "ЊЂ" => "NJĐ",
    "ЂЊ" => "ĐNJ",
    "ЊЕ" => "NJE",
    "ЕЊ" => "ENJ",
    "ЊЖ" => "NJŽ",
    "ЖЊ" => "ŽNJ",
    "ЊЗ" => "NJZ",
    "ЗЊ" => "ZNJ",
    "ЊИ" => "NJI",
    "ИЊ" => "INJ",
    "ЊЈ" => "NJJ",
    "ЈЊ" => "JNJ",
    "ЊК" => "NJK",
    "КЊ" => "KNJ",
    "ЊЛ" => "NJL",
    "ЛЊ" => "LNJ",
    "ЊМ" => "NJM",
    "МЊ" => "MNJ",
    "ЊН" => "NJN",
    "НЊ" => "NNJ",
    "ЊЊ" => "NJNJ",
    "ЊО" => "NJO",
    "ОЊ" => "ONJ",
    "ЊП" => "NJP",
    "ПЊ" => "PNJ",
    "ЊР" => "NJR",
    "РЊ" => "RNJ",
    "ЊС" => "NJS",
    "СЊ" => "SNJ",
    "ЊТ" => "NJT",
    "ТЊ" => "TNJ",
    "ЊЋ" => "NJĆ",
    "ЋЊ" => "ĆNJ",
    "ЊЦ" => "NJC",
    "ЦЊ" => "CNJ",
    "ЊУ" => "NJU",
    "УЊ" => "UNJ",
    "ЊФ" => "NJF",
    "ФЊ" => "FNJ",
    "ЊХ" => "NJH",
    "ХЊ" => "HNJ",
    "ЊЧ" => "NJČ",
    "ЧЊ" => "ČNJ",
    "ЊЏ" => "NJDŽ",
    "ЏЊ" => "DŽNJ",
    "ЊШ" => "NJŠ",
    "ШЊ" => "ŠNJ",
    "ЏА" => "DŽA",
    "АЏ" => "ADŽ",
    "ЏБ" => "DŽB",
    "БЏ" => "BDŽ",
    "ЏВ" => "DŽV",
    "ВЏ" => "VDŽ",
    "ЏГ" => "DŽG",
    "ГЏ" => "GDŽ",
    "ЏД" => "DŽD",
    "ДЏ" => "DDŽ",
    "ЏЂ" => "DŽĐ",
    "ЂЏ" => "ĐDŽ",
    "ЏЕ" => "DŽE",
    "ЕЏ" => "EDŽ",
    "ЏЖ" => "DŽŽ",
    "ЖЏ" => "ŽDŽ",
    "ЏЗ" => "DŽZ",
    "ЗЏ" => "ZDŽ",
    "ЏИ" => "DŽI",
    "ИЏ" => "IDŽ",
    "ЏЈ" => "DŽJ",
    "ЈЏ" => "JDŽ",
    "ЏК" => "DŽK",
    "КЏ" => "KDŽ",
    "ЏЛ" => "DŽL",
    "ЛЏ" => "LDŽ",
    "ЏМ" => "DŽM",
    "МЏ" => "MDŽ",
    "ЏН" => "DŽN",
    "НЏ" => "NDŽ",
    "ЏО" => "DŽO",
    "ОЏ" => "ODŽ",
    "ЏП" => "DŽP",
    "ПЏ" => "PDŽ",
    "ЏР" => "DŽR",
    "РЏ" => "RDŽ",
    "ЏС" => "DŽS",
    "СЏ" => "SDŽ",
    "ЏТ" => "DŽT",
    "ТЏ" => "TDŽ",
    "ЏЋ" => "DŽĆ",
    "ЋЏ" => "ĆDŽ",
    "ЏЦ" => "DŽC",
    "ЦЏ" => "CDŽ",
    "ЏУ" => "DŽU",
    "УЏ" => "UDŽ",
    "ЏФ" => "DŽF",
    "ФЏ" => "FDŽ",
    "ЏХ" => "DŽH",
    "ХЏ" => "HDŽ",
    "ЏЧ" => "DŽČ",
    "ЧЏ" => "ČDŽ",
    "ЏЏ" => "DŽDŽ",
    "ЏШ" => "DŽŠ",
    "ШЏ" => "ŠDŽ",
    'а' => 'a',
    'А' => 'A',
    'б' => 'b',
    'Б' => 'B',
    'в' => 'v',
    'В' => 'V',
    'г' => 'g',
    'Г' => 'G',
    'д' => 'd',
    'Д' => 'D',
    'ђ' => 'đ',
    'Ђ' => 'Đ',
    'е' => 'e',
    'Е' => 'E',
    'ж' => 'ž',
    'Ж' => 'Ž',
    'з' => 'z',
    'З' => 'Z',
    'и' => 'i',
    'И' => 'I',
    'ј' => 'j',
    'Ј' => 'J',
    'к' => 'k',
    'К' => 'K',
    'л' => 'l',
    'Л' => 'L',
    'љ' => 'lj',
    'Љ' => 'Lj',
    'м' => 'm',
    'М' => 'M',
    'н' => 'n',
    'Н' => 'N',
    'њ' => 'nj',
    'Њ' => 'Nj',
    'о' => 'o',
    'О' => 'O',
    'п' => 'p',
    'П' => 'P',
    'р' => 'r',
    'Р' => 'R',
    'с' => 's',
    'С' => 'S',
    'т' => 't',
    'Т' => 'T',
    'ћ' => 'ć',
    'Ћ' => 'Ć',
    'ц' => 'c',
    'Ц' => 'C',
    'у' => 'u',
    'У' => 'U',
    'ф' => 'f',
    'Ф' => 'F',
    'х' => 'h',
    'Х' => 'H',
    'ч' => 'č',
    'Ч' => 'Č',
    'џ' => 'dž',
    'Џ' => 'Dž',
    'ш' => 'š',
    'Ш' => 'Š'
  }

  LATINICA_ASCII_MAP = {
    "ЉA" => "LJA",
    "AЉ" => "ALJ",
    "ЉB" => "LJB",
    "BЉ" => "BLJ",
    "ЉC" => "LJC",
    "CЉ" => "CLJ",
    "ЉD" => "LJD",
    "DЉ" => "DLJ",
    "ЉE" => "LJE",
    "EЉ" => "ELJ",
    "ЉF" => "LJF",
    "FЉ" => "FLJ",
    "ЉG" => "LJG",
    "GЉ" => "GLJ",
    "ЉH" => "LJH",
    "HЉ" => "HLJ",
    "ЉI" => "LJI",
    "IЉ" => "ILJ",
    "ЉJ" => "LJJ",
    "JЉ" => "JLJ",
    "ЉK" => "LJK",
    "KЉ" => "KLJ",
    "ЉL" => "LJL",
    "LЉ" => "LLJ",
    "ЉM" => "LJM",
    "MЉ" => "MLJ",
    "ЉN" => "LJN",
    "NЉ" => "NLJ",
    "ЉO" => "LJO",
    "OЉ" => "OLJ",
    "ЉP" => "LJP",
    "PЉ" => "PLJ",
    "ЉQ" => "LJQ",
    "QЉ" => "QLJ",
    "ЉR" => "LJR",
    "RЉ" => "RLJ",
    "ЉS" => "LJS",
    "SЉ" => "SLJ",
    "ЉT" => "LJT",
    "TЉ" => "TLJ",
    "ЉU" => "LJU",
    "UЉ" => "ULJ",
    "ЉV" => "LJV",
    "VЉ" => "VLJ",
    "ЉW" => "LJW",
    "WЉ" => "WLJ",
    "ЉX" => "LJX",
    "XЉ" => "XLJ",
    "ЉА" => "LJA",
    "АЉ" => "ALJ",
    "ЉБ" => "LJB",
    "БЉ" => "BLJ",
    "ЉВ" => "LJV",
    "ВЉ" => "VLJ",
    "ЉГ" => "LJG",
    "ГЉ" => "GLJ",
    "ЉД" => "LJD",
    "ДЉ" => "DLJ",
    "ЉЂ" => "LJDJ",
    "ЂЉ" => "DJLJ",
    "ЉĐ" => "LJDJ",
    "ĐЉ" => "DJLJ",
    "ЉЕ" => "LJE",
    "ЕЉ" => "ELJ",
    "ЉЖ" => "LJZ",
    "ЖЉ" => "ZLJ",
    "ЉŽ" => "LJZ",
    "ŽЉ" => "ZLJ",
    "ЉЗ" => "LJZ",
    "ЗЉ" => "ZLJ",
    "ЉИ" => "LJI",
    "ИЉ" => "ILJ",
    "ЉЈ" => "LJJ",
    "ЈЉ" => "JLJ",
    "ЉК" => "LJK",
    "КЉ" => "KLJ",
    "ЉЛ" => "LJL",
    "ЛЉ" => "LLJ",
    "ЉЉ" => "LJLJ",
    "ЉМ" => "LJM",
    "МЉ" => "MLJ",
    "ЉН" => "LJN",
    "НЉ" => "NLJ",
    "ЉЊ" => "LJNJ",
    "ЊЉ" => "NJLJ",
    "ЉО" => "LJO",
    "ОЉ" => "OLJ",
    "ЉП" => "LJP",
    "ПЉ" => "PLJ",
    "ЉР" => "LJR",
    "РЉ" => "RLJ",
    "ЉС" => "LJS",
    "СЉ" => "SLJ",
    "ЉТ" => "LJT",
    "ТЉ" => "TLJ",
    "ЉЋ" => "LJC",
    "ЋЉ" => "CLJ",
    "ЉĆ" => "LJC",
    "ĆЉ" => "CLJ",
    "ЉЦ" => "LJC",
    "ЦЉ" => "CLJ",
    "ЉУ" => "LJU",
    "УЉ" => "ULJ",
    "ЉФ" => "LJF",
    "ФЉ" => "FLJ",
    "ЉХ" => "LJH",
    "ХЉ" => "HLJ",
    "ЉЧ" => "LJC",
    "ЧЉ" => "CLJ",
    "ЉČ" => "LJC",
    "ČЉ" => "CLJ",
    "ЉЏ" => "LJDZ",
    "ЏЉ" => "DZLJ",
    "ЉШ" => "LJS",
    "ШЉ" => "SLJ",
    "ЉŠ" => "LJS",
    "ŠЉ" => "SLJ",
    "ЊA" => "NJA",
    "AЊ" => "ANJ",
    "ЊB" => "NJB",
    "BЊ" => "BNJ",
    "ЊC" => "NJC",
    "CЊ" => "CNJ",
    "ЊD" => "NJD",
    "DЊ" => "DNJ",
    "ЊE" => "NJE",
    "EЊ" => "ENJ",
    "ЊF" => "NJF",
    "FЊ" => "FNJ",
    "ЊG" => "NJG",
    "GЊ" => "GNJ",
    "ЊH" => "NJH",
    "HЊ" => "HNJ",
    "ЊI" => "NJI",
    "IЊ" => "INJ",
    "ЊJ" => "NJJ",
    "JЊ" => "JNJ",
    "ЊK" => "NJK",
    "KЊ" => "KNJ",
    "ЊL" => "NJL",
    "LЊ" => "LNJ",
    "ЊM" => "NJM",
    "MЊ" => "MNJ",
    "ЊN" => "NJN",
    "NЊ" => "NNJ",
    "ЊO" => "NJO",
    "OЊ" => "ONJ",
    "ЊP" => "NJP",
    "PЊ" => "PNJ",
    "ЊQ" => "NJQ",
    "QЊ" => "QNJ",
    "ЊR" => "NJR",
    "RЊ" => "RNJ",
    "ЊS" => "NJS",
    "SЊ" => "SNJ",
    "ЊT" => "NJT",
    "TЊ" => "TNJ",
    "ЊU" => "NJU",
    "UЊ" => "UNJ",
    "ЊV" => "NJV",
    "VЊ" => "VNJ",
    "ЊW" => "NJW",
    "WЊ" => "WNJ",
    "ЊX" => "NJX",
    "XЊ" => "XNJ",
    "ЊА" => "NJA",
    "АЊ" => "ANJ",
    "ЊБ" => "NJB",
    "БЊ" => "BNJ",
    "ЊВ" => "NJV",
    "ВЊ" => "VNJ",
    "ЊГ" => "NJG",
    "ГЊ" => "GNJ",
    "ЊД" => "NJD",
    "ДЊ" => "DNJ",
    "ЊЂ" => "NJDJ",
    "ЂЊ" => "DJNJ",
    "ЊĐ" => "NJDJ",
    "ĐЊ" => "DJNJ",
    "ЊЕ" => "NJE",
    "ЕЊ" => "ENJ",
    "ЊЖ" => "NJZ",
    "ЖЊ" => "ZNJ",
    "ЊŽ" => "NJZ",
    "ŽЊ" => "ZNJ",
    "ЊЗ" => "NJZ",
    "ЗЊ" => "ZNJ",
    "ЊИ" => "NJI",
    "ИЊ" => "INJ",
    "ЊЈ" => "NJJ",
    "ЈЊ" => "JNJ",
    "ЊК" => "NJK",
    "КЊ" => "KNJ",
    "ЊЛ" => "NJL",
    "ЛЊ" => "LNJ",
    "ЊМ" => "NJM",
    "МЊ" => "MNJ",
    "ЊН" => "NJN",
    "НЊ" => "NNJ",
    "ЊЊ" => "NJNJ",
    "ЊО" => "NJO",
    "ОЊ" => "ONJ",
    "ЊП" => "NJP",
    "ПЊ" => "PNJ",
    "ЊР" => "NJR",
    "РЊ" => "RNJ",
    "ЊС" => "NJS",
    "СЊ" => "SNJ",
    "ЊТ" => "NJT",
    "ТЊ" => "TNJ",
    "ЊЋ" => "NJC",
    "ЋЊ" => "CNJ",
    "ЊĆ" => "NJC",
    "ĆЊ" => "CNJ",
    "ЊЦ" => "NJC",
    "ЦЊ" => "CNJ",
    "ЊУ" => "NJU",
    "УЊ" => "UNJ",
    "ЊФ" => "NJF",
    "ФЊ" => "FNJ",
    "ЊХ" => "NJH",
    "ХЊ" => "HNJ",
    "ЊЧ" => "NJC",
    "ЧЊ" => "CNJ",
    "ЊČ" => "NJC",
    "ČЊ" => "CNJ",
    "ЊЏ" => "NJDZ",
    "ЏЊ" => "DZNJ",
    "ЊШ" => "NJS",
    "ШЊ" => "SNJ",
    "ЊŠ" => "NJS",
    "ŠЊ" => "SNJ",
    "ЏA" => "DZA",
    "AЏ" => "ADZ",
    "ЏB" => "DZB",
    "BЏ" => "BDZ",
    "ЏC" => "DZC",
    "CЏ" => "CDZ",
    "ЏD" => "DZD",
    "DЏ" => "DDZ",
    "ЏE" => "DZE",
    "EЏ" => "EDZ",
    "ЏF" => "DZF",
    "FЏ" => "FDZ",
    "ЏG" => "DZG",
    "GЏ" => "GDZ",
    "ЏH" => "DZH",
    "HЏ" => "HDZ",
    "ЏI" => "DZI",
    "IЏ" => "IDZ",
    "ЏJ" => "DZJ",
    "JЏ" => "JDZ",
    "ЏK" => "DZK",
    "KЏ" => "KDZ",
    "ЏL" => "DZL",
    "LЏ" => "LDZ",
    "ЏM" => "DZM",
    "MЏ" => "MDZ",
    "ЏN" => "DZN",
    "NЏ" => "NDZ",
    "ЏO" => "DZO",
    "OЏ" => "ODZ",
    "ЏP" => "DZP",
    "PЏ" => "PDZ",
    "ЏQ" => "DZQ",
    "QЏ" => "QDZ",
    "ЏR" => "DZR",
    "RЏ" => "RDZ",
    "ЏS" => "DZS",
    "SЏ" => "SDZ",
    "ЏT" => "DZT",
    "TЏ" => "TDZ",
    "ЏU" => "DZU",
    "UЏ" => "UDZ",
    "ЏV" => "DZV",
    "VЏ" => "VDZ",
    "ЏW" => "DZW",
    "WЏ" => "WDZ",
    "ЏX" => "DZX",
    "XЏ" => "XDZ",
    "ЏА" => "DZA",
    "АЏ" => "ADZ",
    "ЏБ" => "DZB",
    "БЏ" => "BDZ",
    "ЏВ" => "DZV",
    "ВЏ" => "VDZ",
    "ЏГ" => "DZG",
    "ГЏ" => "GDZ",
    "ЏД" => "DZD",
    "ДЏ" => "DDZ",
    "ЏЂ" => "DZDJ",
    "ЂЏ" => "DJDZ",
    "ЏĐ" => "DZDJ",
    "ĐЏ" => "DJDZ",
    "ЏЕ" => "DZE",
    "ЕЏ" => "EDZ",
    "ЏЖ" => "DZZ",
    "ЖЏ" => "ZDZ",
    "ЏŽ" => "DZZ",
    "ŽЏ" => "ZDZ",
    "ЏЗ" => "DZZ",
    "ЗЏ" => "ZDZ",
    "ЏИ" => "DZI",
    "ИЏ" => "IDZ",
    "ЏЈ" => "DZJ",
    "ЈЏ" => "JDZ",
    "ЏК" => "DZK",
    "КЏ" => "KDZ",
    "ЏЛ" => "DZL",
    "ЛЏ" => "LDZ",
    "ЏМ" => "DZM",
    "МЏ" => "MDZ",
    "ЏН" => "DZN",
    "НЏ" => "NDZ",
    "ЏО" => "DZO",
    "ОЏ" => "ODZ",
    "ЏП" => "DZP",
    "ПЏ" => "PDZ",
    "ЏР" => "DZR",
    "РЏ" => "RDZ",
    "ЏС" => "DZS",
    "СЏ" => "SDZ",
    "ЏТ" => "DZT",
    "ТЏ" => "TDZ",
    "ЏЋ" => "DZC",
    "ЋЏ" => "CDZ",
    "ЏĆ" => "DZC",
    "ĆЏ" => "CDZ",
    "ЏЦ" => "DZC",
    "ЦЏ" => "CDZ",
    "ЏУ" => "DZU",
    "УЏ" => "UDZ",
    "ЏФ" => "DZF",
    "ФЏ" => "FDZ",
    "ЏХ" => "DZH",
    "ХЏ" => "HDZ",
    "ЏЧ" => "DZC",
    "ЧЏ" => "CDZ",
    "ЏČ" => "DZC",
    "ČЏ" => "CDZ",
    "ЏЏ" => "DZDZ",
    "ЏШ" => "DZS",
    "ШЏ" => "SDZ",
    "ЏŠ" => "DZS",
    "ŠЏ" => "SDZ",
    "ЂA" => "DJA",
    "AЂ" => "ADJ",
    "ЂB" => "DJB",
    "BЂ" => "BDJ",
    "ЂC" => "DJC",
    "CЂ" => "CDJ",
    "ЂD" => "DJD",
    "DЂ" => "DDJ",
    "ЂE" => "DJE",
    "EЂ" => "EDJ",
    "ЂF" => "DJF",
    "FЂ" => "FDJ",
    "ЂG" => "DJG",
    "GЂ" => "GDJ",
    "ЂH" => "DJH",
    "HЂ" => "HDJ",
    "ЂI" => "DJI",
    "IЂ" => "IDJ",
    "ЂJ" => "DJJ",
    "JЂ" => "JDJ",
    "ЂK" => "DJK",
    "KЂ" => "KDJ",
    "ЂL" => "DJL",
    "LЂ" => "LDJ",
    "ЂM" => "DJM",
    "MЂ" => "MDJ",
    "ЂN" => "DJN",
    "NЂ" => "NDJ",
    "ЂO" => "DJO",
    "OЂ" => "ODJ",
    "ЂP" => "DJP",
    "PЂ" => "PDJ",
    "ЂQ" => "DJQ",
    "QЂ" => "QDJ",
    "ЂR" => "DJR",
    "RЂ" => "RDJ",
    "ЂS" => "DJS",
    "SЂ" => "SDJ",
    "ЂT" => "DJT",
    "TЂ" => "TDJ",
    "ЂU" => "DJU",
    "UЂ" => "UDJ",
    "ЂV" => "DJV",
    "VЂ" => "VDJ",
    "ЂW" => "DJW",
    "WЂ" => "WDJ",
    "ЂX" => "DJX",
    "XЂ" => "XDJ",
    "ЂА" => "DJA",
    "АЂ" => "ADJ",
    "ЂБ" => "DJB",
    "БЂ" => "BDJ",
    "ЂВ" => "DJV",
    "ВЂ" => "VDJ",
    "ЂГ" => "DJG",
    "ГЂ" => "GDJ",
    "ЂД" => "DJD",
    "ДЂ" => "DDJ",
    "ЂЂ" => "DJDJ",
    "ЂĐ" => "DJDJ",
    "ĐЂ" => "DJDJ",
    "ЂЕ" => "DJE",
    "ЕЂ" => "EDJ",
    "ЂЖ" => "DJZ",
    "ЖЂ" => "ZDJ",
    "ЂŽ" => "DJZ",
    "ŽЂ" => "ZDJ",
    "ЂЗ" => "DJZ",
    "ЗЂ" => "ZDJ",
    "ЂИ" => "DJI",
    "ИЂ" => "IDJ",
    "ЂЈ" => "DJJ",
    "ЈЂ" => "JDJ",
    "ЂК" => "DJK",
    "КЂ" => "KDJ",
    "ЂЛ" => "DJL",
    "ЛЂ" => "LDJ",
    "ЂМ" => "DJM",
    "МЂ" => "MDJ",
    "ЂН" => "DJN",
    "НЂ" => "NDJ",
    "ЂО" => "DJO",
    "ОЂ" => "ODJ",
    "ЂП" => "DJP",
    "ПЂ" => "PDJ",
    "ЂР" => "DJR",
    "РЂ" => "RDJ",
    "ЂС" => "DJS",
    "СЂ" => "SDJ",
    "ЂТ" => "DJT",
    "ТЂ" => "TDJ",
    "ЂЋ" => "DJC",
    "ЋЂ" => "CDJ",
    "ЂĆ" => "DJC",
    "ĆЂ" => "CDJ",
    "ЂЦ" => "DJC",
    "ЦЂ" => "CDJ",
    "ЂУ" => "DJU",
    "УЂ" => "UDJ",
    "ЂФ" => "DJF",
    "ФЂ" => "FDJ",
    "ЂХ" => "DJH",
    "ХЂ" => "HDJ",
    "ЂЧ" => "DJC",
    "ЧЂ" => "CDJ",
    "ЂČ" => "DJC",
    "ČЂ" => "CDJ",
    "ЂШ" => "DJS",
    "ШЂ" => "SDJ",
    "ЂŠ" => "DJS",
    "ŠЂ" => "SDJ",
    "ĐA" => "DJA",
    "AĐ" => "ADJ",
    "ĐB" => "DJB",
    "BĐ" => "BDJ",
    "ĐC" => "DJC",
    "CĐ" => "CDJ",
    "ĐD" => "DJD",
    "DĐ" => "DDJ",
    "ĐE" => "DJE",
    "EĐ" => "EDJ",
    "ĐF" => "DJF",
    "FĐ" => "FDJ",
    "ĐG" => "DJG",
    "GĐ" => "GDJ",
    "ĐH" => "DJH",
    "HĐ" => "HDJ",
    "ĐI" => "DJI",
    "IĐ" => "IDJ",
    "ĐJ" => "DJJ",
    "JĐ" => "JDJ",
    "ĐK" => "DJK",
    "KĐ" => "KDJ",
    "ĐL" => "DJL",
    "LĐ" => "LDJ",
    "ĐM" => "DJM",
    "MĐ" => "MDJ",
    "ĐN" => "DJN",
    "NĐ" => "NDJ",
    "ĐO" => "DJO",
    "OĐ" => "ODJ",
    "ĐP" => "DJP",
    "PĐ" => "PDJ",
    "ĐQ" => "DJQ",
    "QĐ" => "QDJ",
    "ĐR" => "DJR",
    "RĐ" => "RDJ",
    "ĐS" => "DJS",
    "SĐ" => "SDJ",
    "ĐT" => "DJT",
    "TĐ" => "TDJ",
    "ĐU" => "DJU",
    "UĐ" => "UDJ",
    "ĐV" => "DJV",
    "VĐ" => "VDJ",
    "ĐW" => "DJW",
    "WĐ" => "WDJ",
    "ĐX" => "DJX",
    "XĐ" => "XDJ",
    "ĐА" => "DJA",
    "АĐ" => "ADJ",
    "ĐБ" => "DJB",
    "БĐ" => "BDJ",
    "ĐВ" => "DJV",
    "ВĐ" => "VDJ",
    "ĐГ" => "DJG",
    "ГĐ" => "GDJ",
    "ĐД" => "DJD",
    "ДĐ" => "DDJ",
    "ĐĐ" => "DJDJ",
    "ĐЕ" => "DJE",
    "ЕĐ" => "EDJ",
    "ĐЖ" => "DJZ",
    "ЖĐ" => "ZDJ",
    "ĐŽ" => "DJZ",
    "ŽĐ" => "ZDJ",
    "ĐЗ" => "DJZ",
    "ЗĐ" => "ZDJ",
    "ĐИ" => "DJI",
    "ИĐ" => "IDJ",
    "ĐЈ" => "DJJ",
    "ЈĐ" => "JDJ",
    "ĐК" => "DJK",
    "КĐ" => "KDJ",
    "ĐЛ" => "DJL",
    "ЛĐ" => "LDJ",
    "ĐМ" => "DJM",
    "МĐ" => "MDJ",
    "ĐН" => "DJN",
    "НĐ" => "NDJ",
    "ĐО" => "DJO",
    "ОĐ" => "ODJ",
    "ĐП" => "DJP",
    "ПĐ" => "PDJ",
    "ĐР" => "DJR",
    "РĐ" => "RDJ",
    "ĐС" => "DJS",
    "СĐ" => "SDJ",
    "ĐТ" => "DJT",
    "ТĐ" => "TDJ",
    "ĐЋ" => "DJC",
    "ЋĐ" => "CDJ",
    "ĐĆ" => "DJC",
    "ĆĐ" => "CDJ",
    "ĐЦ" => "DJC",
    "ЦĐ" => "CDJ",
    "ĐУ" => "DJU",
    "УĐ" => "UDJ",
    "ĐФ" => "DJF",
    "ФĐ" => "FDJ",
    "ĐХ" => "DJH",
    "ХĐ" => "HDJ",
    "ĐЧ" => "DJC",
    "ЧĐ" => "CDJ",
    "ĐČ" => "DJC",
    "ČĐ" => "CDJ",
    "ĐШ" => "DJS",
    "ШĐ" => "SDJ",
    "ĐŠ" => "DJS",
    "ŠĐ" => "SDJ",
    "A" => "A",
    "B" => "B",
    "C" => "C",
    "D" => "D",
    "E" => "E",
    "F" => "F",
    "G" => "G",
    "H" => "H",
    "I" => "I",
    "J" => "J",
    "K" => "K",
    "L" => "L",
    "M" => "M",
    "N" => "N",
    "O" => "O",
    "P" => "P",
    "Q" => "Q",
    "R" => "R",
    "S" => "S",
    "T" => "T",
    "U" => "U",
    "V" => "V",
    "W" => "W",
    "X" => "X",
    "А" => "A",
    "Б" => "B",
    "В" => "V",
    "Г" => "G",
    "Д" => "D",
    "Ђ" => "Dj",
    "Đ" => "Dj",
    "Е" => "E",
    "Ж" => "Z",
    "Ž" => "Z",
    "З" => "Z",
    "И" => "I",
    "Ј" => "J",
    "К" => "K",
    "Л" => "L",
    "Љ" => "Lj",
    "М" => "M",
    "Н" => "N",
    "Њ" => "Nj",
    "О" => "O",
    "П" => "P",
    "Р" => "R",
    "С" => "S",
    "Т" => "T",
    "Ћ" => "C",
    "Ć" => "C",
    "Ц" => "C",
    "У" => "U",
    "Ф" => "F",
    "Х" => "H",
    "Ч" => "C",
    "Č" => "C",
    "Џ" => "Dz",
    "Ш" => "S",
    "Š" => "S",
    "a" => "a",
    "b" => "b",
    "c" => "c",
    "d" => "d",
    "e" => "e",
    "f" => "f",
    "g" => "g",
    "h" => "h",
    "i" => "i",
    "j" => "j",
    "k" => "k",
    "l" => "l",
    "m" => "m",
    "n" => "n",
    "o" => "o",
    "p" => "p",
    "q" => "q",
    "r" => "r",
    "s" => "s",
    "t" => "t",
    "u" => "u",
    "v" => "v",
    "w" => "w",
    "x" => "x",
    "а" => "a",
    "б" => "b",
    "в" => "v",
    "г" => "g",
    "д" => "d",
    "ђ" => "dj",
    "đ" => "dj",
    "е" => "e",
    "ж" => "z",
    "ž" => "z",
    "з" => "z",
    "и" => "i",
    "ј" => "j",
    "к" => "k",
    "л" => "l",
    "љ" => "lj",
    "м" => "m",
    "н" => "n",
    "њ" => "nj",
    "о" => "o",
    "п" => "p",
    "р" => "r",
    "с" => "s",
    "т" => "t",
    "ћ" => "c",
    "ć" => "c",
    "ц" => "c",
    "у" => "u",
    "ф" => "f",
    "х" => "h",
    "ч" => "c",
    "č" => "c",
    "џ" => "dz",
    "ш" => "s",
    "š" => "s",
  }

  LATINICOM_REGEXP = Regexp.union(LATINICA_FULL_MAP.keys)

  LATINICA_ASCII_REGEXP = Regexp.union(LATINICA_ASCII_MAP.keys)

  def latinicom(text)
    text.gsub(LATINICOM_REGEXP, LATINICA_FULL_MAP)
  end

  def latinicom_ascii(text)
    text.gsub(LATINICA_ASCII_REGEXP, LATINICA_ASCII_MAP)
  end

  def abeceda
    ABECEDA
  end

  extend self

end
